@@ -519,7 +519,7 @@ void BGGameScene::MusicFinished()
 {
   if (MusicEnabled && AudioEnabled)
   {
-    Music->setCurrentSource(GetFileName("music.mp3"));
+    Music->setCurrentSource(GetFileName("music.ogg"));
     Music->play();
   }
 }
